-- Name: Valley Patrol
-- Author: Delta99
-- Date Created: 17 Jan 2016
--
-- Initially adopted from AIB-005 - Patrol AI and Randomize Zones Moose Test Missions.
-- reworked after AI_CAP_ZONE was added to Moose Framework and AI_PATROLZONE changed.

-- Define the SET of CLIENTs from the red coalition. This SET is filled during startup.
local RU_PlanesClientSet = SET_CLIENT:New():FilterCountries( "RUSSIA" ):FilterCategories( "plane" )

-- We define an array of potential spawn planes (using templates from the editor).
-- The InitCleanup will attempt to cleanup planes stuck at the airbase.
-- The InitRandomizeTemplate picks a random plane from the RU_PlanesList to spawn using
-- "AI_RU" template from the editor.
local RU_PlanesList = {'AI RU 1', 'AI RU 2', 'AI RU 3'}
local RU_PlanesSpawn = SPAWN:New( "AI RU" ):InitRandomizeTemplate(RU_PlanesList):InitCleanUp( 30 )

-- Start the AI_BALANCER, using the SET of red CLIENTs, and the SPAWN object as a parameter.
-- Using the AI_BALANCER allows the AI to take these planes if there are no human players for their spots.
-- InitSpawnInterval sets the interval between min and max seconds to spawn so that they are not all
-- spawned right away.
local RU_AI_Balancer = AI_BALANCER:New( RU_PlanesClientSet, RU_PlanesSpawn ):InitSpawnInterval(30, 180)

-- Create the first polygon zone ...
local PatrolZoneGroup1 = GROUP:FindByName( "PatrolZone1" )
local PatrolZone1 = ZONE_POLYGON:New( "PatrolZone1", PatrolZoneGroup1 )

-- Create the second polygon zone ...
local PatrolZoneGroup2 = GROUP:FindByName( "PatrolZone2" )
local PatrolZone2 = ZONE_POLYGON:New( "PatrolZone2", PatrolZoneGroup2 )

-- Now, create an array of these zones ...
local PatrolZoneArray = { PatrolZone1, PatrolZone2 }

local EngageZoneAll = GROUP:FindByName( "EngageZoneAll" )
local CapEngageZone = ZONE_POLYGON:New( "EngageZoneAll", EngageZoneAll )

function RU_AI_Balancer:OnAfterSpawned( SetGroup, From, Event, To, AIGroup )
  -- For now set the Patrol Zone and Engagement Zone to the same. Was having issues when I
  -- used the patrol zones from above as the engagement zones as well so instead creating
  -- a new one here that encompasses both.

  local ranPatrolZone = PatrolZoneArray[math.random( 1, 2 )]
  local PatrolCAPZone = AI_CAP_ZONE:New(ranPatrolZone, 60, 9750, 460, 1200)
  PatrolCAPZone:ManageFuel(0.2, 60)
  PatrolCAPZone:SetControllable(AIGroup)
  
  -- Try using a different engagement zone than the patrol zone
  PatrolCAPZone:SetEngageZone(CapEngageZone)
  --PatrolCAPZone:SetEngageZone(ranPatrolZone)
  PatrolCAPZone:__Start(1)
end
